#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_IMAG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_IMAG_HPP_INCLUDED

#include <nt2/complex/include/functions/scalar/imag.hpp>

#endif
